pitchtools.chromatic_pitch_name_to_diatonic_pitch_class_number
==============================================================

.. autofunction:: abjad.tools.pitchtools.chromatic_pitch_name_to_diatonic_pitch_class_number
